@@ -82,6 +82,7 @@ mob <- function(formula, data, subset, na.action, weights, offset, cluster,
   if(xreg) {
     attr(X, "formula") <- formula(formula, rhs = 1L)
     attr(X, "terms") <- mtY
+    attr(X, "offset") <- cl$offset
   }
   Z <- Formula::model.part(formula, mf, rhs = 2L)
   n <- nrow(Z)
@@ -182,6 +183,7 @@ mob_partynode <- function(Y, X, Z, weights = NULL, offset = NULL, cluster = NULL
       attr(sx, "xlevels")   <- attr(x, "xlevels")
       attr(sx, "formula")   <- attr(x, "formula")
       attr(sx, "terms")     <- attr(x, "terms")
+      attr(sx, "offset")    <- attr(x, "offset")
       sx
     }
   } else {
@@ -827,6 +829,7 @@ refit.modelparty <- function(object, node = NULL, drop = TRUE, ...)
   if(!is.null(X)) {
     attr(X, "formula") <- formula(object$info$Formula, rhs = 1L)
     attr(X, "terms") <- object$info$terms$response
+    attr(X, "offset") <- object$info$call$offset
   }
 
   suby <- function(y, index) {
@@ -839,6 +842,7 @@ refit.modelparty <- function(object, node = NULL, drop = TRUE, ...)
       attr(sx, "xlevels")   <- attr(x, "xlevels")
       attr(sx, "formula")   <- attr(x, "formula")
       attr(sx, "terms")     <- attr(x, "terms")
+      attr(sx, "offset")    <- attr(x, "offset")
       sx
     }
   } else {
